==> ejc-panhuo-api-3.0.0-20200819.095051-19-sources.jar: com/ejianc/business/panhuo/vo/AddressVO.java <==
package com.ejianc.business.panhuo.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 地址管理
 * 
 * @author generator
 * 
 */
public class AddressVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String projectName; // 项目名称
    private java.lang.Long projectId; // 项目主键
    private java.lang.Long orgId; // 组织主键
    private java.lang.String orgName; // 组织名称
    private java.lang.Long userId; // 用户主键
    private java.lang.Double lon; // 经度
    private java.lang.Double lat; // 纬度
    private java.lang.String firstLocation; // 所在地一级区域
    private java.lang.String secondLocation; // 所在地二级区域
    private java.lang.String thirdLocation; // 所在地三级区域
    private java.lang.String fourthLocation; // 所在地四级区域
    private java.lang.String location; // 所在地末级区域
    private java.lang.String address; // 详细地址
    private java.lang.String phone; // 联系方式
    private java.lang.String name; // 联系人
    private java.lang.Integer isquote; // 0=是，1=不是

    public Double getLon() {
        return lon;
    }

    public void setLon(Double lon) {
        this.lon = lon;
    }

    public Double getLat() {
        return lat;
    }

    public void setLat(Double lat) {
        this.lat = lat;
    }

    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    @ReferSerialTransfer(referCode="market-project")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 组织主键
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织主键
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 用户主键
     */
    public java.lang.Long getUserId() {
        return userId;
    }

    /**
     * 用户主键
     */
    public void setUserId(java.lang.Long userId) {
        this.userId = userId;
    }
    /**
     * 所在地一级区域
     */
    public java.lang.String getFirstLocation() {
        return firstLocation;
    }

    /**
     * 所在地一级区域
     */
    public void setFirstLocation(java.lang.String firstLocation) {
        this.firstLocation = firstLocation;
    }
    /**
     * 所在地二级区域
     */
    public java.lang.String getSecondLocation() {
        return secondLocation;
    }

    /**
     * 所在地二级区域
     */
    public void setSecondLocation(java.lang.String secondLocation) {
        this.secondLocation = secondLocation;
    }
    /**
     * 所在地三级区域
     */
    public java.lang.String getThirdLocation() {
        return thirdLocation;
    }

    /**
     * 所在地三级区域
     */
    public void setThirdLocation(java.lang.String thirdLocation) {
        this.thirdLocation = thirdLocation;
    }
    /**
     * 所在地四级区域
     */
    public java.lang.String getFourthLocation() {
        return fourthLocation;
    }

    /**
     * 所在地四级区域
     */
    public void setFourthLocation(java.lang.String fourthLocation) {
        this.fourthLocation = fourthLocation;
    }
    /**
     * 所在地末级区域
     */
    public java.lang.String getLocation() {
        return location;
    }

    /**
     * 所在地末级区域
     */
    public void setLocation(java.lang.String location) {
        this.location = location;
    }
    /**
     * 详细地址
     */
    public java.lang.String getAddress() {
        return address;
    }

    /**
     * 详细地址
     */
    public void setAddress(java.lang.String address) {
        this.address = address;
    }
    /**
     * 联系方式
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系方式
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }
    /**
     * 联系人
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 联系人
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 0=是，1=不是
     */
    public java.lang.Integer getIsquote() {
        return isquote;
    }

    /**
     * 0=是，1=不是
     */
    public void setIsquote(java.lang.Integer isquote) {
        this.isquote = isquote;
    }
    
}

==> ejc-panhuo-api-3.0.0-20200820.014936-20-sources.jar: com/ejianc/business/panhuo/vo/AddressVO.java <==
package com.ejianc.business.panhuo.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 地址管理
 * 
 * @author generator
 * 
 */
public class AddressVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String projectName; // 项目名称
    private java.lang.Long projectId; // 项目主键
    private java.lang.Long orgId; // 组织主键
    private java.lang.String orgName; // 组织名称
    private java.lang.Long userId; // 用户主键
    private java.lang.Double lon; // 经度
    private java.lang.Double lat; // 纬度
    private java.lang.String firstLocation; // 所在地一级区域
    private java.lang.String secondLocation; // 所在地二级区域
    private java.lang.String thirdLocation; // 所在地三级区域
    private java.lang.String fourthLocation; // 所在地四级区域
    private java.lang.String location; // 所在地末级区域
    private java.lang.String address; // 详细地址
    private java.lang.String project_address; // 项目地址
    private java.lang.String detail_address; // 地址
    private java.lang.String phone; // 联系方式
    private java.lang.String name; // 联系人
    private java.lang.Integer isquote; // 0=是，1=不是

    public Double getLon() {
        return lon;
    }

    public void setLon(Double lon) {
        this.lon = lon;
    }

    public Double getLat() {
        return lat;
    }

    public void setLat(Double lat) {
        this.lat = lat;
    }

    public String getProject_address() {
        return project_address;
    }

    public void setProject_address(String project_address) {
        this.project_address = project_address;
    }

    public String getDetail_address() {
        return detail_address;
    }

    public void setDetail_address(String detail_address) {
        this.detail_address = detail_address;
    }

    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    @ReferSerialTransfer(referCode="market-project")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 组织主键
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织主键
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 用户主键
     */
    public java.lang.Long getUserId() {
        return userId;
    }

    /**
     * 用户主键
     */
    public void setUserId(java.lang.Long userId) {
        this.userId = userId;
    }
    /**
     * 所在地一级区域
     */
    public java.lang.String getFirstLocation() {
        return firstLocation;
    }

    /**
     * 所在地一级区域
     */
    public void setFirstLocation(java.lang.String firstLocation) {
        this.firstLocation = firstLocation;
    }
    /**
     * 所在地二级区域
     */
    public java.lang.String getSecondLocation() {
        return secondLocation;
    }

    /**
     * 所在地二级区域
     */
    public void setSecondLocation(java.lang.String secondLocation) {
        this.secondLocation = secondLocation;
    }
    /**
     * 所在地三级区域
     */
    public java.lang.String getThirdLocation() {
        return thirdLocation;
    }

    /**
     * 所在地三级区域
     */
    public void setThirdLocation(java.lang.String thirdLocation) {
        this.thirdLocation = thirdLocation;
    }
    /**
     * 所在地四级区域
     */
    public java.lang.String getFourthLocation() {
        return fourthLocation;
    }

    /**
     * 所在地四级区域
     */
    public void setFourthLocation(java.lang.String fourthLocation) {
        this.fourthLocation = fourthLocation;
    }
    /**
     * 所在地末级区域
     */
    public java.lang.String getLocation() {
        return location;
    }

    /**
     * 所在地末级区域
     */
    public void setLocation(java.lang.String location) {
        this.location = location;
    }
    /**
     * 详细地址
     */
    public java.lang.String getAddress() {
        return address;
    }

    /**
     * 详细地址
     */
    public void setAddress(java.lang.String address) {
        this.address = address;
    }
    /**
     * 联系方式
     */
    public java.lang.String getPhone() {
        return phone;
    }

    /**
     * 联系方式
     */
    public void setPhone(java.lang.String phone) {
        this.phone = phone;
    }
    /**
     * 联系人
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 联系人
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 0=是，1=不是
     */
    public java.lang.Integer getIsquote() {
        return isquote;
    }

    /**
     * 0=是，1=不是
     */
    public void setIsquote(java.lang.Integer isquote) {
        this.isquote = isquote;
    }
    
}
